@@ -89,7 +89,7 @@ public class FtpWagon
 
         if ( authInfo == null )
         {
-            throw new IllegalArgumentException( "Authentication Credentials cannot be null for FTP protocol" );
+            throw new NullPointerException( "authenticationInfo cannot be null" );
         }
 
         if ( authInfo.getUserName() == null )
@@ -112,7 +112,7 @@ public class FtpWagon
 
         String host = getRepository().getHost();
 
-        ftp = new FTPClient();
+        ftp = createClient();
         ftp.setDefaultTimeout( getTimeout() );
         ftp.setDataTimeout( getTimeout() );
         ftp.setControlEncoding( getControlEncoding() );
@@ -187,6 +187,11 @@ public class FtpWagon
         }
     }
 
+    protected FTPClient createClient()
+    {
+        return new FTPClient();
+    }
+
     protected void firePutCompleted( Resource resource, File file )
     {
         try
@@ -404,7 +409,7 @@ public class FtpWagon
     }
 
     /**
-     * 
+     *
      */
     public class PrintCommandListener
         implements ProtocolCommandListener
@@ -661,6 +666,9 @@ public class FtpWagon
                             + ftp.getReplyString();
                     throw new TransferFailedException( msg );
                 }
+
+                sourceFileStream.close();
+                sourceFileStream = null;
             }
             catch ( IOException e )
             {
