@@ -25,16 +25,18 @@ import java.util.List;
 
 import junit.framework.TestCase;
 
-import org.apache.log4j.Logger;
 import org.apache.maven.wagon.TransferFailedException;
 
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+
 /**
  * Unit Tests for the HtmlFileListParser
  */
 public class HtmlFileListParserTest
     extends TestCase
 {
-    private static Logger logger = Logger.getLogger( HtmlFileListParserTest.class );
+    private static Logger logger = LoggerFactory.getLogger( HtmlFileListParserTest.class );
 
     private void assertContainsExpected( List<String> links, String[] expected )
     {
