@@ -25,10 +25,9 @@ import org.apache.http.HttpException;
 import org.apache.http.HttpHost;
 import org.apache.http.HttpResponse;
 import org.apache.http.HttpStatus;
-import org.apache.http.auth.AUTH;
 import org.apache.http.auth.AuthScope;
+import org.apache.http.auth.ChallengeState;
 import org.apache.http.auth.Credentials;
-import org.apache.http.auth.MalformedChallengeException;
 import org.apache.http.auth.NTCredentials;
 import org.apache.http.auth.UsernamePasswordCredentials;
 import org.apache.http.client.AuthCache;
@@ -132,11 +131,16 @@ public abstract class AbstractHttpClientWagon
                     byte[] bytes = IOUtil.toByteArray( stream );
                     byteBuffer = ByteBuffer.allocate( bytes.length );
                     byteBuffer.put( bytes );
+                    stream.close();
                 }
                 catch ( IOException e )
                 {
                     throw new TransferFailedException( e.getMessage(), e );
                 }
+                finally
+                {
+                    IOUtil.close( stream );
+                }
             }
             this.resource = resource;
             this.length = resource == null ? -1 : resource.getContentLength();
@@ -164,12 +168,12 @@ public abstract class AbstractHttpClientWagon
             return true;
         }
 
-        public void writeTo( final OutputStream outstream )
+        public void writeTo( final OutputStream outputStream )
             throws IOException
         {
-            if ( outstream == null )
+            if ( outputStream == null )
             {
-                throw new IllegalArgumentException( "Output stream may not be null" );
+                throw new NullPointerException( "outputStream cannot be null" );
             }
             TransferEvent transferEvent =
                 new TransferEvent( wagon, resource, TransferEvent.TRANSFER_PROGRESS, TransferEvent.REQUEST_PUT );
@@ -187,7 +191,7 @@ public abstract class AbstractHttpClientWagon
                     while ( ( l = instream.read( buffer ) ) != -1 )
                     {
                         fireTransferProgress( transferEvent, buffer, -1 );
-                        outstream.write( buffer, 0, l );
+                        outputStream.write( buffer, 0, l );
                     }
                 }
                 else
@@ -202,7 +206,7 @@ public abstract class AbstractHttpClientWagon
                             break;
                         }
                         fireTransferProgress( transferEvent, buffer, (int) Math.min( BUFFER_SIZE, remaining ) );
-                        outstream.write( buffer, 0, l );
+                        outputStream.write( buffer, 0, l );
                         remaining -= l;
                     }
                 }
@@ -364,7 +368,7 @@ public abstract class AbstractHttpClientWagon
         return connManager;
     }
 
-    private static final CloseableHttpClient CLIENT = createClient();
+    private static CloseableHttpClient httpClient = createClient();
 
     private static CloseableHttpClient createClient()
     {
@@ -379,8 +383,6 @@ public abstract class AbstractHttpClientWagon
 
     private AuthCache authCache;
 
-    private HttpClientContext localContext;
-
     private Closeable closeable;
 
     /**
@@ -410,11 +412,8 @@ public abstract class AbstractHttpClientWagon
     {
         repository.setUrl( getURL( repository ) );
 
-        localContext = HttpClientContext.create();
         credentialsProvider = new BasicCredentialsProvider();
         authCache = new BasicAuthCache();
-        localContext.setCredentialsProvider( credentialsProvider );
-        localContext.setAuthCache( authCache );
 
         if ( authenticationInfo != null )
         {
@@ -455,9 +454,9 @@ public abstract class AbstractHttpClientWagon
                         creds = new UsernamePasswordCredentials( proxyUsername, proxyPassword );
                     }
 
-                    int port = proxyInfo.getPort();
+                    int proxyPort = proxyInfo.getPort();
 
-                    AuthScope authScope = getProxyBasicAuthScope().getScope( proxyHost, port );
+                    AuthScope authScope = getProxyBasicAuthScope().getScope( proxyHost, proxyPort );
                     credentialsProvider.setCredentials( authScope, creds );
                 }
             }
@@ -470,6 +469,18 @@ public abstract class AbstractHttpClientWagon
         {
             httpClientConnectionManager.closeIdleConnections( 0, TimeUnit.MILLISECONDS );
         }
+
+        if ( authCache != null )
+        {
+            authCache.clear();
+            authCache = null;
+        }
+
+        if ( credentialsProvider != null )
+        {
+            credentialsProvider.clear();
+            credentialsProvider = null;
+        }
     }
 
     public static void setPersistentPool( boolean persistentPool )
@@ -481,6 +492,7 @@ public abstract class AbstractHttpClientWagon
         PoolingHttpClientConnectionManager poolingHttpClientConnectionManager )
     {
         httpClientConnectionManager = poolingHttpClientConnectionManager;
+        httpClient = createClient();
     }
 
     public void put( File source, String resourceName )
@@ -553,11 +565,11 @@ public abstract class AbstractHttpClientWagon
         }
         catch ( HttpException he )
         {
-            fireTransferError( resource, he, TransferEvent.REQUEST_GET );
+            fireTransferError( resource, he, TransferEvent.REQUEST_PUT );
         }
         catch ( IOException e )
         {
-            fireTransferError( resource, e, TransferEvent.REQUEST_GET );
+            fireTransferError( resource, e, TransferEvent.REQUEST_PUT );
         }
 
         // preemptive for put
@@ -570,15 +582,7 @@ public abstract class AbstractHttpClientWagon
         if ( credentialsProvider.getCredentials( targetScope ) != null )
         {
             BasicScheme targetAuth = new BasicScheme();
-            try
-            {
-                targetAuth.processChallenge( new BasicHeader( AUTH.WWW_AUTH, "BASIC preemptive" ) );
-                authCache.put( targetHost, targetAuth );
-            }
-            catch ( MalformedChallengeException ignore )
-            {
-                // ignore
-            }
+            authCache.put( targetHost, targetAuth );
         }
 
         HttpPut putMethod = new HttpPut( url );
@@ -780,8 +784,20 @@ public abstract class AbstractHttpClientWagon
         else
         {
             requestConfigBuilder.setSocketTimeout( getReadTimeout() );
+            if ( httpMethod instanceof HttpPut )
+            {
+                requestConfigBuilder.setExpectContinueEnabled( true );
+            }
         }
 
+        if ( httpMethod instanceof HttpPut )
+        {
+            requestConfigBuilder.setRedirectsEnabled( false );
+        }
+
+        HttpClientContext localContext = HttpClientContext.create();
+        localContext.setCredentialsProvider( credentialsProvider );
+        localContext.setAuthCache( authCache );
         localContext.setRequestConfig( requestConfigBuilder.build() );
 
         if ( config != null && config.isUsePreemptive() )
@@ -792,7 +808,6 @@ public abstract class AbstractHttpClientWagon
             if ( credentialsProvider.getCredentials( targetScope ) != null )
             {
                 BasicScheme targetAuth = new BasicScheme();
-                targetAuth.processChallenge( new BasicHeader( AUTH.WWW_AUTH, "BASIC preemptive" ) );
                 authCache.put( targetHost, targetAuth );
             }
         }
@@ -804,32 +819,19 @@ public abstract class AbstractHttpClientWagon
                 HttpHost proxyHost = new HttpHost( proxyInfo.getHost(), proxyInfo.getPort() );
                 AuthScope proxyScope = getProxyBasicAuthScope().getScope( proxyHost );
 
-                String proxyUsername = proxyInfo.getUserName();
-                String proxyPassword = proxyInfo.getPassword();
-                String proxyNtlmHost = proxyInfo.getNtlmHost();
-                String proxyNtlmDomain = proxyInfo.getNtlmDomain();
-
-                if ( proxyUsername != null && proxyPassword != null )
+                if ( credentialsProvider.getCredentials( proxyScope ) != null )
                 {
-                    Credentials creds;
-                    if ( proxyNtlmHost != null || proxyNtlmDomain != null )
-                    {
-                        creds = new NTCredentials( proxyUsername, proxyPassword, proxyNtlmHost, proxyNtlmDomain );
-                    }
-                    else
-                    {
-                        creds = new UsernamePasswordCredentials( proxyUsername, proxyPassword );
-                    }
-
-                    credentialsProvider.setCredentials( proxyScope, creds );
-                    BasicScheme proxyAuth = new BasicScheme();
-                    proxyAuth.processChallenge( new BasicHeader( AUTH.PROXY_AUTH, "BASIC preemptive" ) );
+                    /* This is extremely ugly because we need to set challengeState to PROXY, but
+                     * the constructor is deprecated. Alternatively, we could subclass BasicScheme
+                     * to ProxyBasicScheme and set the state internally in the constructor.
+                     */
+                    BasicScheme proxyAuth = new BasicScheme( ChallengeState.PROXY );
                     authCache.put( proxyHost, proxyAuth );
                 }
             }
         }
 
-        return CLIENT.execute( httpMethod, localContext );
+        return httpClient.execute( httpMethod, localContext );
     }
 
     protected void setHeaders( HttpUriRequest method )
@@ -1143,4 +1145,4 @@ public abstract class AbstractHttpClientWagon
     {
         return MAX_BACKOFF_WAIT_SECONDS;
     }
-}
\ No newline at end of file
+}
