@@ -20,13 +20,11 @@ package org.apache.maven.wagon.providers.ssh.jsch;
  */
 
 import java.io.BufferedReader;
+import java.io.ByteArrayInputStream;
 import java.io.File;
 import java.io.FileNotFoundException;
 import java.io.IOException;
-import java.io.InputStream;
 import java.io.InputStreamReader;
-import java.io.PrintWriter;
-import java.io.StringWriter;
 import java.util.List;
 import java.util.Properties;
 
@@ -48,17 +46,13 @@ import org.apache.maven.wagon.providers.ssh.interactive.InteractiveUserInfo;
 import org.apache.maven.wagon.providers.ssh.interactive.NullInteractiveUserInfo;
 import org.apache.maven.wagon.providers.ssh.jsch.interactive.UserInfoUIKeyboardInteractiveProxy;
 import org.apache.maven.wagon.providers.ssh.knownhost.KnownHostChangedException;
+import org.apache.maven.wagon.providers.ssh.knownhost.KnownHostEntry;
 import org.apache.maven.wagon.providers.ssh.knownhost.KnownHostsProvider;
 import org.apache.maven.wagon.providers.ssh.knownhost.UnknownHostException;
 import org.apache.maven.wagon.proxy.ProxyInfo;
 import org.apache.maven.wagon.resource.Resource;
 import org.codehaus.plexus.util.IOUtil;
-import org.codehaus.plexus.util.StringInputStream;
 
-import com.jcraft.jsch.agentproxy.AgentProxyException;
-import com.jcraft.jsch.agentproxy.Connector;
-import com.jcraft.jsch.agentproxy.ConnectorFactory;
-import com.jcraft.jsch.agentproxy.RemoteIdentityRepository;
 import com.jcraft.jsch.ChannelExec;
 import com.jcraft.jsch.HostKey;
 import com.jcraft.jsch.HostKeyRepository;
@@ -71,6 +65,10 @@ import com.jcraft.jsch.ProxySOCKS5;
 import com.jcraft.jsch.Session;
 import com.jcraft.jsch.UIKeyboardInteractive;
 import com.jcraft.jsch.UserInfo;
+import com.jcraft.jsch.agentproxy.AgentProxyException;
+import com.jcraft.jsch.agentproxy.Connector;
+import com.jcraft.jsch.agentproxy.ConnectorFactory;
+import com.jcraft.jsch.agentproxy.RemoteIdentityRepository;
 
 /**
  * AbstractJschWagon
@@ -83,6 +81,8 @@ public abstract class AbstractJschWagon
 
     protected Session session;
 
+    private String strictHostKeyChecking;
+
     /**
      * @plexus.requirement role-hint="file"
      */
@@ -93,6 +93,11 @@ public abstract class AbstractJschWagon
      */
     private volatile InteractiveUserInfo interactiveUserInfo;
 
+    /**
+     * @plexus.configuration default-value="gssapi-with-mic,publickey,password,keyboard-interactive"
+     */
+    private volatile String preferredAuthentications;
+
     /**
      * @plexus.requirement
      */
@@ -128,20 +133,7 @@ public abstract class AbstractJschWagon
             throw new AuthenticationException( e.getMessage() );
         }
 
-        try
-        {
-            Connector connector = ConnectorFactory.getDefault().createConnector();
-            if ( connector != null )
-            {
-                IdentityRepository repo = new RemoteIdentityRepository( connector );
-                sch.setIdentityRepository( repo );
-            }
-        }
-        catch ( AgentProxyException e )
-        {
-            fireSessionDebug( "Unable to connect to agent: " + e.toString() );
-        }
-
+        //can only pick one method of authentication
         if ( privateKey != null && privateKey.exists() )
         {
             fireSessionDebug( "Using private key: " + privateKey );
@@ -154,6 +146,23 @@ public abstract class AbstractJschWagon
                 throw new AuthenticationException( "Cannot connect. Reason: " + e.getMessage(), e );
             }
         }
+        else
+        {
+            try
+            {
+                Connector connector = ConnectorFactory.getDefault().createConnector();
+                if ( connector != null )
+                {
+                    IdentityRepository repo = new RemoteIdentityRepository( connector );
+                    sch.setIdentityRepository( repo );
+                }
+            }
+            catch ( AgentProxyException e )
+            {
+                fireSessionDebug( "Unable to connect to agent: " + e.toString() );
+            }
+
+        }
 
         String host = getRepository().getHost();
         int port =
@@ -226,19 +235,23 @@ public abstract class AbstractJschWagon
                 String contents = getKnownHostsProvider().getContents();
                 if ( contents != null )
                 {
-                    sch.setKnownHosts( new StringInputStream( contents ) );
+                    sch.setKnownHosts( new ByteArrayInputStream( contents.getBytes() ) );
                 }
             }
             catch ( JSchException e )
             {
                 // continue without known_hosts
             }
-            config.setProperty( "StrictHostKeyChecking", getKnownHostsProvider().getHostKeyChecking() );
+            if ( strictHostKeyChecking == null )
+            {
+                strictHostKeyChecking = getKnownHostsProvider().getHostKeyChecking();
+            }
+            config.setProperty( "StrictHostKeyChecking", strictHostKeyChecking );
         }
 
         if ( authenticationInfo.getPassword() != null )
         {
-            config.setProperty( "PreferredAuthentications", "gssapi-with-mic,publickey,password,keyboard-interactive" );
+            config.setProperty( "PreferredAuthentications", preferredAuthentications );
         }
 
         config.setProperty( "BatchMode", interactive ? "no" : "yes" );
@@ -247,24 +260,9 @@ public abstract class AbstractJschWagon
 
         session.setUserInfo( ui );
 
-        StringWriter stringWriter = new StringWriter();
         try
         {
             session.connect();
-
-            if ( getKnownHostsProvider() != null )
-            {
-                PrintWriter w = new PrintWriter( stringWriter );
-
-                HostKeyRepository hkr = sch.getHostKeyRepository();
-                HostKey[] keys = hkr.getHostKey();
-
-                for ( int i = 0; keys != null && i < keys.length; i++ )
-                {
-                    HostKey key = keys[i];
-                    w.println( key.getHost() + " " + key.getType() + " " + key.getKey() );
-                }
-            }
         }
         catch ( JSchException e )
         {
@@ -282,16 +280,30 @@ public abstract class AbstractJschWagon
             }
         }
 
-        try
+        if ( getKnownHostsProvider() != null )
         {
-            getKnownHostsProvider().storeKnownHosts( stringWriter.toString() );
-        }
-        catch ( IOException e )
-        {
-            closeConnection();
+            HostKeyRepository hkr = sch.getHostKeyRepository();
 
-            throw new AuthenticationException(
-                "Connection aborted - failed to write to known_hosts. Reason: " + e.getMessage(), e );
+            HostKey[] hk = hkr.getHostKey( host, null );
+            try
+            {
+                if ( hk != null )
+                {
+                    for ( HostKey hostKey : hk )
+                    {
+                        KnownHostEntry knownHostEntry = new KnownHostEntry( hostKey.getHost(), hostKey.getType(),
+                            hostKey.getKey() );
+                        getKnownHostsProvider().addKnownHost( knownHostEntry );
+                    }
+                }
+            }
+            catch ( IOException e )
+            {
+                closeConnection();
+
+                throw new AuthenticationException(
+                    "Connection aborted - failed to write to known_hosts. Reason: " + e.getMessage(), e );
+            }
         }
     }
 
@@ -304,31 +316,42 @@ public abstract class AbstractJschWagon
         }
     }
 
-    public Streams executeCommand( String command, boolean ignoreFailures )
+    public Streams executeCommand( String command, boolean ignoreStdErr, boolean ignoreNoneZeroExitCode )
         throws CommandExecutionException
     {
         ChannelExec channel = null;
         BufferedReader stdoutReader = null;
         BufferedReader stderrReader = null;
+        Streams streams = null;
         try
         {
             channel = (ChannelExec) session.openChannel( EXEC_CHANNEL );
 
+            fireSessionDebug( "Executing: " + command );
             channel.setCommand( command + "\n" );
 
-            InputStream stdout = channel.getInputStream();
-            InputStream stderr = channel.getErrStream();
+            stdoutReader = new BufferedReader( new InputStreamReader( channel.getInputStream() ) );
+            stderrReader = new BufferedReader( new InputStreamReader( channel.getErrStream() ) );
 
             channel.connect();
 
-            stdoutReader = new BufferedReader( new InputStreamReader( stdout ) );
-            stderrReader = new BufferedReader( new InputStreamReader( stderr ) );
+            streams = CommandExecutorStreamProcessor.processStreams( stderrReader, stdoutReader );
 
-            Streams streams = CommandExecutorStreamProcessor.processStreams( stderrReader, stdoutReader );
+            stdoutReader.close();
+            stdoutReader = null;
 
-            if ( streams.getErr().length() > 0 && !ignoreFailures )
+            stderrReader.close();
+            stderrReader = null;
+
+            int exitCode = channel.getExitStatus();
+
+            if ( streams.getErr().length() > 0 && !ignoreStdErr )
+            {
+                throw new CommandExecutionException( "Exit code: " + exitCode + " - " + streams.getErr() );
+            }
+
+            if ( exitCode != 0 && !ignoreNoneZeroExitCode )
             {
-                int exitCode = channel.getExitStatus();
                 throw new CommandExecutionException( "Exit code: " + exitCode + " - " + streams.getErr() );
             }
 
@@ -344,6 +367,12 @@ public abstract class AbstractJschWagon
         }
         finally
         {
+            if ( streams != null )
+            {
+                fireSessionDebug( "Stdout results:" + streams.getOut() );
+                fireSessionDebug( "Stderr results:" + streams.getErr() );
+            }
+
             IOUtil.close( stdoutReader );
             IOUtil.close( stderrReader );
             if ( channel != null )
@@ -396,6 +425,15 @@ public abstract class AbstractJschWagon
         executeCommand( command, false );
     }
 
+    public Streams executeCommand( String command, boolean ignoreFailures )
+            throws CommandExecutionException
+    {
+        fireTransferDebug( "Executing command: " + command );
+
+        //backward compatible with wagon 2.10
+        return executeCommand( command, ignoreFailures, ignoreFailures );
+    }
+
     public InteractiveUserInfo getInteractiveUserInfo()
     {
         return this.interactiveUserInfo;
@@ -415,4 +453,29 @@ public abstract class AbstractJschWagon
     {
         this.knownHostsProvider = knownHostsProvider;
     }
+
+    public void setUIKeyboardInteractive( UIKeyboardInteractive uIKeyboardInteractive )
+    {
+        this.uIKeyboardInteractive = uIKeyboardInteractive;
+    }
+
+    public String getPreferredAuthentications()
+    {
+        return preferredAuthentications;
+    }
+
+    public void setPreferredAuthentications( String preferredAuthentications )
+    {
+        this.preferredAuthentications = preferredAuthentications;
+    }
+
+    public String getStrictHostKeyChecking()
+    {
+        return strictHostKeyChecking;
+    }
+
+    public void setStrictHostKeyChecking( String strictHostKeyChecking )
+    {
+        this.strictHostKeyChecking = strictHostKeyChecking;
+    }
 }
