@@ -40,7 +40,6 @@ import org.apache.commons.httpclient.params.HttpMethodParams;
 import org.apache.commons.httpclient.util.DateParseException;
 import org.apache.commons.httpclient.util.DateUtil;
 import org.apache.commons.io.IOUtils;
-import org.apache.commons.lang.StringUtils;
 import org.apache.maven.wagon.InputData;
 import org.apache.maven.wagon.OutputData;
 import org.apache.maven.wagon.PathUtils;
@@ -103,11 +102,16 @@ public abstract class AbstractHttpClientWagon
                     byte[] bytes = IOUtils.toByteArray( stream );
                     this.byteBuffer = ByteBuffer.allocate( bytes.length );
                     this.byteBuffer.put( bytes );
+                    stream.close();
                 }
                 catch ( IOException e )
                 {
                     throw new TransferFailedException( e.getMessage(), e );
                 }
+                finally
+                {
+                    IOUtils.closeQuietly( stream );
+                }
             }
 
             this.resource = resource;
@@ -160,6 +164,9 @@ public abstract class AbstractHttpClientWagon
 
                     remaining -= n;
                 }
+
+                fin.close();
+                fin = null;
             }
             finally
             {
@@ -206,7 +213,7 @@ public abstract class AbstractHttpClientWagon
         {
             username = authenticationInfo.getUserName();
 
-            if ( StringUtils.contains( username, "\\" ) )
+            if ( username != null && username.contains( "\\" ) )
             {
                 String[] domainAndUsername = username.split( "\\\\" );
                 domain = domainAndUsername[0];
@@ -220,7 +227,8 @@ public abstract class AbstractHttpClientWagon
 
         String host = getRepository().getHost();
 
-        if ( StringUtils.isNotEmpty( username ) && StringUtils.isNotEmpty( password ) )
+        if ( !( username == null || username.length() == 0 )
+            && !( password == null || password.length() == 0 ) )
         {
             Credentials creds;
             if ( domain != null )
@@ -350,7 +358,7 @@ public abstract class AbstractHttpClientWagon
         }
         catch ( IOException e )
         {
-            fireTransferError( resource, e, TransferEvent.REQUEST_GET );
+            fireTransferError( resource, e, TransferEvent.REQUEST_PUT );
         }
 
         PutMethod putMethod = new PutMethod( url );
@@ -571,7 +579,7 @@ public abstract class AbstractHttpClientWagon
             }
         }
     }
-    
+
     private static final String DEFAULT_USER_AGENT = getDefaultUserAgent();
 
     private static String getDefaultUserAgent()
@@ -585,6 +593,8 @@ public abstract class AbstractHttpClientWagon
             try
             {
                 props.load( is );
+                is.close();
+                is = null;
             }
             catch ( IOException ignore )
             {
